@@ -34,6 +34,7 @@ class DXJobLogStreamingException(Exception):
 class DXJobLogStreamClient(WebSocketBaseClient):
     def __init__(self, job_id, input_params={}, msg_output_format="{job} {level} {msg}", msg_callback=None,
                  print_job_info=True):
+        self.job_id = job_id
         self.seen_jobs = {}
         self.input_params = input_params
         self.msg_output_format = msg_output_format
@@ -68,6 +69,8 @@ class DXJobLogStreamClient(WebSocketBaseClient):
                                                                                    reason=self.closed_reason)
                 raise DXJobLogStreamingException(error)
         elif self.print_job_info:
+            if self.job_id not in self.seen_jobs:
+                self.seen_jobs[self.job_id] = {}
             for job_id in self.seen_jobs:
                 print get_find_jobs_string(dxpy.describe(job_id), has_children=False, show_outputs=True)
 
